==> idoit-api-1.15.zip: src/classes/modules/api/classmap.php <==
<?php
/**
 * Classmap for "api" generated on 2023-02-13
 */

return array (
  'isys_api' => 'src/classes/modules/api/isys_api.class.php',
  'isys_api_controller' => 'src/classes/modules/api/controller/isys_api_controller.class.php',
  'isys_api_controller_jsonrpc' => 'src/classes/modules/api/controller/isys_api_controller_jsonrpc.class.php',
  'isys_api_model' => 'src/classes/modules/api/model/isys_api_model.class.php',
  'isys_api_model_cmdb' => 'src/classes/modules/api/model/isys_api_model_cmdb.class.php',
  'isys_api_model_cmdb_categories' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_categories.class.php',
  'isys_api_model_cmdb_category' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_category.class.php',
  'isys_api_model_cmdb_category_info' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_category_info.class.php',
  'isys_api_model_cmdb_condition' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_condition.class.php',
  'isys_api_model_cmdb_contact' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_contact.class.php',
  'isys_api_model_cmdb_dialog' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_dialog.class.php',
  'isys_api_model_cmdb_filter' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_filter.class.php',
  'isys_api_model_cmdb_impact' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_impact.class.php',
  'isys_api_model_cmdb_ip_search' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_ip_search.class.php',
  'isys_api_model_cmdb_location_tree' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_location_tree.class.php',
  'isys_api_model_cmdb_logbook' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_logbook.class.php',
  'isys_api_model_cmdb_object' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_object.class.php',
  'isys_api_model_cmdb_object_type_categories' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_object_type_categories.class.php',
  'isys_api_model_cmdb_object_type_groups' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_object_type_groups.class.php',
  'isys_api_model_cmdb_object_types' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_object_types.class.php',
  'isys_api_model_cmdb_objects' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_objects.class.php',
  'isys_api_model_cmdb_objects_by_relation' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_objects_by_relation.class.php',
  'isys_api_model_cmdb_reports' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_reports.class.php',
  'isys_api_model_cmdb_status' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_status.class.php',
  'isys_api_model_cmdb_workstation_components' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_workstation_components.class.php',
  'isys_api_model_console' => 'src/classes/modules/api/model/isys_api_model_console.class.php',
  'isys_api_model_console_auth' => 'src/classes/modules/api/model/console/isys_api_model_console_auth.class.php',
  'isys_api_model_console_commands' => 'src/classes/modules/api/model/console/isys_api_model_console_commands.class.php',
  'isys_api_model_console_document' => 'src/classes/modules/api/model/console/isys_api_model_console_document.class.php',
  'isys_api_model_console_dynamicgroups' => 'src/classes/modules/api/model/console/isys_api_model_console_dynamicgroups.class.php',
  'isys_api_model_console_import' => 'src/classes/modules/api/model/console/isys_api_model_console_import.class.php',
  'isys_api_model_console_ldap' => 'src/classes/modules/api/model/console/isys_api_model_console_ldap.class.php',
  'isys_api_model_console_logbook' => 'src/classes/modules/api/model/console/isys_api_model_console_logbook.class.php',
  'isys_api_model_console_notifications' => 'src/classes/modules/api/model/console/isys_api_model_console_notifications.class.php',
  'isys_api_model_console_report' => 'src/classes/modules/api/model/console/isys_api_model_console_report.class.php',
  'isys_api_model_console_search' => 'src/classes/modules/api/model/console/isys_api_model_console_search.class.php',
  'isys_api_model_console_settings' => 'src/classes/modules/api/model/console/isys_api_model_console_settings.class.php',
  'isys_api_model_console_system' => 'src/classes/modules/api/model/console/isys_api_model_console_system.class.php',
  'isys_api_model_console_tenant' => 'src/classes/modules/api/model/console/isys_api_model_console_tenant.class.php',
  'isys_api_model_idoit' => 'src/classes/modules/api/model/isys_api_model_idoit.class.php',
  'isys_api_model_idoit_addons' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_addons.class.php',
  'isys_api_model_idoit_constants' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_constants.class.php',
  'isys_api_model_idoit_license' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_license.class.php',
  'isys_api_model_idoit_login' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_login.class.php',
  'isys_api_model_idoit_logout' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_logout.class.php',
  'isys_api_model_idoit_search' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_search.class.php',
  'isys_api_model_idoit_version' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_version.class.php',
  'isys_api_model_interface' => 'src/classes/modules/api/model/isys_api_model_interface.class.php',
  'isys_api_view' => 'src/classes/modules/api/view/isys_api_view.class.php',
  'isys_api_view_json' => 'src/classes/modules/api/view/isys_api_view_json.class.php',
  'isys_module_api' => 'src/classes/modules/api/isys_module_api.class.php',
  'isys_module_api_autoload' => 'src/classes/modules/api/isys_module_api_autoload.class.php',
  'isys_module_api_install' => 'src/classes/modules/api/install/isys_module_api_install.class.php',
);

==> idoit-api-1.16.zip: src/classes/modules/api/classmap.php <==
<?php
/**
 * Classmap for "api" generated on 2023-02-13
 */

return array (
  'isys_api' => 'src/classes/modules/api/isys_api.class.php',
  'isys_api_controller' => 'src/classes/modules/api/controller/isys_api_controller.class.php',
  'isys_api_controller_jsonrpc' => 'src/classes/modules/api/controller/isys_api_controller_jsonrpc.class.php',
  'isys_api_model' => 'src/classes/modules/api/model/isys_api_model.class.php',
  'isys_api_model_cmdb' => 'src/classes/modules/api/model/isys_api_model_cmdb.class.php',
  'isys_api_model_cmdb_cabling' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_cabling.class.php',
  'isys_api_model_cmdb_categories' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_categories.class.php',
  'isys_api_model_cmdb_category' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_category.class.php',
  'isys_api_model_cmdb_category_info' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_category_info.class.php',
  'isys_api_model_cmdb_condition' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_condition.class.php',
  'isys_api_model_cmdb_contact' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_contact.class.php',
  'isys_api_model_cmdb_dialog' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_dialog.class.php',
  'isys_api_model_cmdb_filter' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_filter.class.php',
  'isys_api_model_cmdb_impact' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_impact.class.php',
  'isys_api_model_cmdb_ip_search' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_ip_search.class.php',
  'isys_api_model_cmdb_location_tree' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_location_tree.class.php',
  'isys_api_model_cmdb_logbook' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_logbook.class.php',
  'isys_api_model_cmdb_object' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_object.class.php',
  'isys_api_model_cmdb_object_type_categories' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_object_type_categories.class.php',
  'isys_api_model_cmdb_object_type_groups' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_object_type_groups.class.php',
  'isys_api_model_cmdb_object_types' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_object_types.class.php',
  'isys_api_model_cmdb_objects' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_objects.class.php',
  'isys_api_model_cmdb_objects_by_relation' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_objects_by_relation.class.php',
  'isys_api_model_cmdb_reports' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_reports.class.php',
  'isys_api_model_cmdb_status' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_status.class.php',
  'isys_api_model_cmdb_workstation_components' => 'src/classes/modules/api/model/cmdb/isys_api_model_cmdb_workstation_components.class.php',
  'isys_api_model_console' => 'src/classes/modules/api/model/isys_api_model_console.class.php',
  'isys_api_model_console_auth' => 'src/classes/modules/api/model/console/isys_api_model_console_auth.class.php',
  'isys_api_model_console_commands' => 'src/classes/modules/api/model/console/isys_api_model_console_commands.class.php',
  'isys_api_model_console_document' => 'src/classes/modules/api/model/console/isys_api_model_console_document.class.php',
  'isys_api_model_console_dynamicgroups' => 'src/classes/modules/api/model/console/isys_api_model_console_dynamicgroups.class.php',
  'isys_api_model_console_import' => 'src/classes/modules/api/model/console/isys_api_model_console_import.class.php',
  'isys_api_model_console_ldap' => 'src/classes/modules/api/model/console/isys_api_model_console_ldap.class.php',
  'isys_api_model_console_logbook' => 'src/classes/modules/api/model/console/isys_api_model_console_logbook.class.php',
  'isys_api_model_console_notifications' => 'src/classes/modules/api/model/console/isys_api_model_console_notifications.class.php',
  'isys_api_model_console_report' => 'src/classes/modules/api/model/console/isys_api_model_console_report.class.php',
  'isys_api_model_console_search' => 'src/classes/modules/api/model/console/isys_api_model_console_search.class.php',
  'isys_api_model_console_settings' => 'src/classes/modules/api/model/console/isys_api_model_console_settings.class.php',
  'isys_api_model_console_system' => 'src/classes/modules/api/model/console/isys_api_model_console_system.class.php',
  'isys_api_model_console_tenant' => 'src/classes/modules/api/model/console/isys_api_model_console_tenant.class.php',
  'isys_api_model_idoit' => 'src/classes/modules/api/model/isys_api_model_idoit.class.php',
  'isys_api_model_idoit_addons' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_addons.class.php',
  'isys_api_model_idoit_constants' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_constants.class.php',
  'isys_api_model_idoit_license' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_license.class.php',
  'isys_api_model_idoit_login' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_login.class.php',
  'isys_api_model_idoit_logout' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_logout.class.php',
  'isys_api_model_idoit_search' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_search.class.php',
  'isys_api_model_idoit_version' => 'src/classes/modules/api/model/idoit/isys_api_model_idoit_version.class.php',
  'isys_api_model_interface' => 'src/classes/modules/api/model/isys_api_model_interface.class.php',
  'isys_api_model_option_interface' => 'src/classes/modules/api/model/isys_api_model_option_interface.class.php',
  'isys_api_view' => 'src/classes/modules/api/view/isys_api_view.class.php',
  'isys_api_view_json' => 'src/classes/modules/api/view/isys_api_view_json.class.php',
  'isys_module_api' => 'src/classes/modules/api/isys_module_api.class.php',
  'isys_module_api_autoload' => 'src/classes/modules/api/isys_module_api_autoload.class.php',
  'isys_module_api_install' => 'src/classes/modules/api/install/isys_module_api_install.class.php',
);
